# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgumentType

from gvm.protocols.gmpv9 import EntityType


class GmpGetAggregatesTestCase:
    def test_get_aggregates(self):
        self.gmp.get_aggregates(EntityType.ALERT)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="alert"/>'
        )

        self.gmp.get_aggregates(resource_type=EntityType.CERT_BUND_ADV)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="cert_bund_adv"/>'
        )

        self.gmp.get_aggregates(EntityType.CPE)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="cpe"/>'
        )

        self.gmp.get_aggregates(EntityType.CVE)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="cve"/>'
        )

        self.gmp.get_aggregates(EntityType.DFN_CERT_ADV)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="dfn_cert_adv"/>'
        )

        self.gmp.get_aggregates(EntityType.HOST)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="host"/>'
        )

        self.gmp.get_aggregates(EntityType.NOTE)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="note"/>'
        )

        self.gmp.get_aggregates(EntityType.NVT)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="nvt"/>'
        )

        self.gmp.get_aggregates(EntityType.OPERATING_SYSTEM)

        self.connection.send.has_been_called_with('<get_aggregates type="os"/>')

        self.gmp.get_aggregates(EntityType.OVALDEF)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="ovaldef"/>'
        )

        self.gmp.get_aggregates(EntityType.OVERRIDE)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="override"/>'
        )

        self.gmp.get_aggregates(EntityType.REPORT)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="report"/>'
        )

        self.gmp.get_aggregates(EntityType.RESULT)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="result"/>'
        )

        self.gmp.get_aggregates(EntityType.TASK)

        self.connection.send.has_been_called_with(
            '<get_aggregates type="task"/>'
        )

    def test_get_aggregates_kwargs(self):
        self.gmp.get_aggregates(EntityType.ALERT, group_column="family")

        self.connection.send.has_been_called_with(
            '<get_aggregates type="alert" group_column="family"/>'
        )

    def test_get_aggregates_missing_resource_type(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_aggregates(resource_type=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_aggregates(resource_type='')

        with self.assertRaises(RequiredArgument):
            self.gmp.get_aggregates('')

    def test_get_aggregates_invalid_resource_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.get_aggregates(resource_type='foo')


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


class CallableMock:
    def __init__(self, name):
        self.name = name
        self.calls = []
        self.result = None

    def __call__(self, *args, **kwargs):
        self.calls.append({'args': args, 'kwargs': kwargs})

        return self.result

    def return_value(self, value):
        self.result = value

    def has_not_been_called(self):
        assert len(self.calls) == 0, "{0} has been called.".format(self.name)

    def has_been_called(self):
        assert len(self.calls) > 0, "{0} has not been called.".format(self.name)

    def has_been_called_times(self, times):
        assert len(self.calls) == times, (
            "{name} has not been called {times}"
            " times.".format(name=self.name, times=times)
        )

    def has_been_called_with(self, *args, **kwargs):
        if len(self.calls) == 0:
            assert False

        lastcall = self.calls[-1]

        # not sure if this is correct
        assert lastcall['args'] == args and lastcall['kwargs'] == kwargs, (
            "Expected arguments {eargs} {ekwargs} of {name} do not match."
            "Received: {rargs} {rkwargs}".format(
                name=self.name,
                eargs=args,
                ekwargs=kwargs,
                rargs=lastcall['args'],
                rkwargs=lastcall['kwargs'],
            )
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2018 - 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# pylint: disable=arguments-differ, redefined-builtin, too-many-lines

"""
Module for communication with gvmd in
`Greenbone Management Protocol version 20.08`_

.. _Greenbone Management Protocol version 20.08:
    https://docs.greenbone.net/API/GMP/gmp-20.08.html
"""
import warnings

from typing import Any, List, Optional, Callable

from gvm.utils import deprecation
from gvm.xml import XmlCommand

from gvm.protocols.gmpv7.gmpv7 import _to_bool, _to_comma_list
from gvm.connections import GvmConnection
from gvm.errors import InvalidArgumentType, RequiredArgument

from gvm.protocols.base import GvmProtocol

from . import types
from .types import *  # pylint: disable=unused-wildcard-import, wildcard-import

_EMPTY_POLICY_ID = '085569ce-73ed-11df-83c3-002264764cea'

PROTOCOL_VERSION = (20, 8)


class GmpV208Mixin(GvmProtocol):
    types = types

    def __init__(
        self,
        connection: GvmConnection,
        *,
        transform: Optional[Callable[[str], Any]] = None
    ):
        super().__init__(connection, transform=transform)

        # Is authenticated on gvmd
        self._authenticated = False

    def create_agent(
        self,
        installer: str,
        signature: str,
        name: str,
        *,
        comment: Optional[str] = None,
        howto_install: Optional[str] = None,
        howto_use: Optional[str] = None
    ) -> None:
        # pylint: disable=unused-argument
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.create_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def clone_agent(self, agent_id: str) -> None:
        # pylint: disable=unused-argument
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.clone_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def modify_agent(
        self,
        agent_id: str,
        *,
        name: Optional[str] = None,
        comment: Optional[str] = None
    ) -> None:
        # pylint: disable=unused-argument
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.clone_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def delete_agent(
        self,
        agent_id: str,
        *,
        ultimate: Optional[bool] = False
        # pylint: disable=unused-argument
    ) -> None:
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.delete_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def verify_agent(self, agent_id: str) -> None:
        # pylint: disable=unused-argument
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.verify_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def get_agent(self, agent_id: str) -> None:
        # pylint: disable=unused-argument
        deprecation(
            "{} has been removed in GMP version {}.{}".format(
                self.get_agent.__name__,
                self.get_protocol_version()[0],
                self.get_protocol_version()[1],
            )
        )

    def get_info(self, info_id: str, info_type: InfoType) -> Any:
        """Request a single secinfo

        Arguments:
            info_id: UUID of an existing secinfo
            info_type: Type must be either CERT_BUND_ADV, CPE, CVE,
                DFN_CERT_ADV, OVALDEF, NVT

        Returns:
            The response. See :py:meth:`send_command` for details.
        """
        if not info_type:
            raise RequiredArgument(
                function=self.get_info.__name__, argument='info_type'
            )

        if not isinstance(info_type, InfoType):
            raise InvalidArgumentType(
                function=self.get_info.__name__,
                argument='info_type',
                arg_type=InfoType.__name__,
            )

        if not info_id:
            raise RequiredArgument(
                function=self.get_info.__name__, argument='info_id'
            )

        cmd = XmlCommand("get_info")
        cmd.set_attribute("info_id", info_id)

        cmd.set_attribute("type", info_type.value)

        # for single entity always request all details
        cmd.set_attribute("details", "1")
        return self._send_xml_command(cmd)

    def create_target(
        self,
        name: str,
        *,
        make_unique: Optional[bool] = None,
        asset_hosts_filter: Optional[str] = None,
        hosts: Optional[List[str]] = None,
        comment: Optional[str] = None,
        exclude_hosts: Optional[List[str]] = None,
        ssh_credential_id: Optional[str] = None,
        ssh_credential_port: Optional[int] = None,
        smb_credential_id: Optional[str] = None,
        esxi_credential_id: Optional[str] = None,
        snmp_credential_id: Optional[str] = None,
        alive_test: Optional[AliveTest] = None,
        reverse_lookup_only: Optional[bool] = None,
        reverse_lookup_unify: Optional[bool] = None,
        port_range: Optional[str] = None,
        port_list_id: Optional[str] = None
    ) -> Any:
        """Create a new target

        Arguments:
            name: Name of the target
            make_unique: Deprecated. Will be ignored.
            asset_hosts_filter: Filter to select target host from assets hosts
            hosts: List of hosts addresses to scan
            exclude_hosts: List of hosts addresses to exclude from scan
            comment: Comment for the target
            ssh_credential_id: UUID of a ssh credential to use on target
            ssh_credential_port: The port to use for ssh credential
            smb_credential_id: UUID of a smb credential to use on target
            snmp_credential_id: UUID of a snmp credential to use on target
            esxi_credential_id: UUID of a esxi credential to use on target
            alive_test: Which alive test to use
            reverse_lookup_only: Whether to scan only hosts that have names
            reverse_lookup_unify: Whether to scan only one IP when multiple IPs
                have the same name.
            port_range: Port range for the target
            port_list_id: UUID of the port list to use on target

        Returns:
            The response. See :py:meth:`send_command` for details.
        """

        cmd = XmlCommand("create_target")
        _xmlname = cmd.add_element("name", name)

        if make_unique is not None:
            warnings.warn(
                'create_target make_unique argument is deprecated '
                'and will be ignored.',
                DeprecationWarning,
            )

        if not name:
            raise RequiredArgument(
                function=self.create_target.__name__, argument='name'
            )

        if asset_hosts_filter:
            cmd.add_element(
                "asset_hosts", attrs={"filter": str(asset_hosts_filter)}
            )
        elif hosts:
            cmd.add_element("hosts", _to_comma_list(hosts))
        else:
            raise RequiredArgument(
                function=self.create_target.__name__,
                argument='hosts or asset_hosts_filter',
            )

        if comment:
            cmd.add_element("comment", comment)

        if exclude_hosts:
            cmd.add_element("exclude_hosts", _to_comma_list(exclude_hosts))

        if ssh_credential_id:
            _xmlssh = cmd.add_element(
                "ssh_credential", attrs={"id": ssh_credential_id}
            )
            if ssh_credential_port:
                _xmlssh.add_element("port", str(ssh_credential_port))

        if smb_credential_id:
            cmd.add_element("smb_credential", attrs={"id": smb_credential_id})

        if esxi_credential_id:
            cmd.add_element("esxi_credential", attrs={"id": esxi_credential_id})

        if snmp_credential_id:
            cmd.add_element("snmp_credential", attrs={"id": snmp_credential_id})

        if alive_test:
            if not isinstance(alive_test, AliveTest):
                raise InvalidArgumentType(
                    function=self.create_target.__name__,
                    argument='alive_test',
                    arg_type=AliveTest.__name__,
                )

            cmd.add_element("alive_tests", alive_test.value)

        if reverse_lookup_only is not None:
            cmd.add_element(
                "reverse_lookup_only", _to_bool(reverse_lookup_only)
            )

        if reverse_lookup_unify is not None:
            cmd.add_element(
                "reverse_lookup_unify", _to_bool(reverse_lookup_unify)
            )

        # since 20.08 one of port_range or port_list_id is required!
        if not port_range and not port_list_id:
            raise RequiredArgument(
                function=self.create_target.__name__,
                argument='port_range or port_list_id',
            )

        if port_range:
            cmd.add_element("port_range", port_range)

        if port_list_id:
            cmd.add_element("port_list", attrs={"id": port_list_id})

        return self._send_xml_command(cmd)



# -*- coding: utf-8 -*-
# Copyright (C) 2020 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# pylint: disable=too-many-lines,redefined-builtin

"""
Module for communication with gvmd in
`Greenbone Management Protocol version 21.04`_

.. _Greenbone Management Protocol version 21.04:
    https://docs.greenbone.net/API/GMP/gmp-21.04.html
"""

from typing import Any, Callable, Optional

from gvm.protocols.gmpv214.gmpv214 import GmpV214Mixin
from gvm.protocols.gmpv208.gmpv208 import GmpV208Mixin
from gvm.protocols.gmpv9.gmpv9 import GmpV9Mixin
from gvm.protocols.gmpv8.gmpv8 import GmpV8Mixin
from gvm.protocols.gmpv7.gmpv7 import GmpV7Mixin
from gvm.connections import GvmConnection


from . import types
from .types import *  # pylint: disable=unused-wildcard-import, wildcard-import

PROTOCOL_VERSION = (21, 4)


class Gmp(GmpV214Mixin, GmpV208Mixin, GmpV9Mixin, GmpV8Mixin, GmpV7Mixin):

    types = types

    def __init__(
        self,
        connection: GvmConnection,
        *,
        transform: Optional[Callable[[str], Any]] = None
    ):
        super().__init__(connection, transform=transform)

        # Is authenticated on gvmd
        self._authenticated = False

    @staticmethod
    def get_protocol_version() -> tuple:
        """Determine the Greenbone Management Protocol version.

        Returns:
            tuple: Implemented version of the Greenbone Management Protocol
        """
        return PROTOCOL_VERSION



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
from enum import Enum

from typing import Optional

from gvm.errors import InvalidArgument

from gvm.protocols.gmpv8.types import (
    AliveTest,
    AssetType,
    CredentialFormat,
    CredentialType,
    FeedType,
    HostsOrdering,
    InfoType,
    PermissionSubjectType,
    PortRangeType,
    ReportFormatType,
    SeverityLevel,
    SnmpAuthAlgorithm,
    SnmpPrivacyAlgorithm,
    TicketStatus,
    TimeUnit,
    get_alive_test_from_string,
    get_asset_type_from_string,
    get_credential_format_from_string,
    get_credential_type_from_string,
    get_feed_type_from_string,
    get_hosts_ordering_from_string,
    get_info_type_from_string,
    get_permission_subject_type_from_string,
    get_port_range_type_from_string,
    get_report_format_id_from_string,
    get_severity_level_from_string,
    get_snmp_auth_algorithm_from_string,
    get_snmp_privacy_algorithm_from_string,
    get_ticket_status_from_string,
    get_time_unit_from_string,
)


__all__ = [
    "AlertCondition",
    "AlertEvent",
    "AlertMethod",
    "AliveTest",
    "AssetType",
    "CredentialFormat",
    "CredentialType",
    "EntityType",
    "FeedType",
    "FilterType",
    "HostsOrdering",
    "InfoType",
    "PermissionSubjectType",
    "PortRangeType",
    "ReportFormatType",
    "ScannerType",
    "SeverityLevel",
    "SnmpAuthAlgorithm",
    "SnmpPrivacyAlgorithm",
    "TicketStatus",
    "TimeUnit",
    "get_alert_condition_from_string",
    "get_alert_event_from_string",
    "get_alert_method_from_string",
    "get_alive_test_from_string",
    "get_asset_type_from_string",
    "get_credential_format_from_string",
    "get_credential_type_from_string",
    "get_entity_type_from_string",
    "get_feed_type_from_string",
    "get_filter_type_from_string",
    "get_hosts_ordering_from_string",
    "get_info_type_from_string",
    "get_permission_subject_type_from_string",
    "get_port_range_type_from_string",
    "get_report_format_id_from_string",
    "get_scanner_type_from_string",
    "get_severity_level_from_string",
    "get_snmp_auth_algorithm_from_string",
    "get_snmp_privacy_algorithm_from_string",
    "get_ticket_status_from_string",
    "get_time_unit_from_string",
]


class EntityType(Enum):
    """Enum for entity types """

    AGENT = "agent"
    ALERT = "alert"
    ASSET = "asset"
    CERT_BUND_ADV = "cert_bund_adv"
    CPE = "cpe"
    CREDENTIAL = "credential"
    CVE = "cve"
    DFN_CERT_ADV = "dfn_cert_adv"
    FILTER = "filter"
    GROUP = "group"
    HOST = "host"
    INFO = "info"
    NOTE = "note"
    NVT = "nvt"
    OPERATING_SYSTEM = "os"
    OVALDEF = "ovaldef"
    OVERRIDE = "override"
    PERMISSION = "permission"
    PORT_LIST = "port_list"
    REPORT = "report"
    REPORT_FORMAT = "report_format"
    RESULT = "result"
    ROLE = "role"
    SCAN_CONFIG = "config"
    SCANNER = "scanner"
    SCHEDULE = "schedule"
    TAG = "tag"
    TARGET = "target"
    TASK = "task"
    TICKET = "ticket"
    TLS_CERTIFICATE = "tls_certificate"
    USER = "user"
    VULNERABILITY = "vuln"


def get_entity_type_from_string(
    entity_type: Optional[str],
) -> Optional[EntityType]:
    """Convert a entity type string to an actual EntityType instance

    Arguments:
        entity_type: Entity type string to convert to a EntityType
    """
    if not entity_type:
        return None

    if entity_type == 'vuln':
        return EntityType.VULNERABILITY

    if entity_type == 'os':
        return EntityType.OPERATING_SYSTEM

    if entity_type == 'config':
        return EntityType.SCAN_CONFIG

    if entity_type == 'tls_certificate':
        return EntityType.TLS_CERTIFICATE

    try:
        return EntityType[entity_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='entity_type',
            function=get_entity_type_from_string.__name__,
        ) from None


class AlertEvent(Enum):
    """Enum for alert event types """

    TASK_RUN_STATUS_CHANGED = 'Task run status changed'
    UPDATED_SECINFO_ARRIVED = 'Updated SecInfo arrived'
    NEW_SECINFO_ARRIVED = 'New SecInfo arrived'
    TICKET_RECEIVED = 'Ticket received'
    ASSIGNED_TICKET_CHANGED = 'Assigned ticket changed'
    OWNED_TICKET_CHANGED = 'Owned ticket changed'


def get_alert_event_from_string(
    alert_event: Optional[str],
) -> Optional[AlertEvent]:
    """Convert an alert event string into a AlertEvent instance """
    if not alert_event:
        return None

    alert_event = alert_event.lower()

    if alert_event == 'task run status changed':
        return AlertEvent.TASK_RUN_STATUS_CHANGED

    if alert_event == 'updated secinfo arrived':
        return AlertEvent.UPDATED_SECINFO_ARRIVED

    if alert_event == 'new secinfo arrived':
        return AlertEvent.NEW_SECINFO_ARRIVED

    if alert_event == 'ticket received':
        return AlertEvent.TICKET_RECEIVED

    if alert_event == 'assigned ticket changed':
        return AlertEvent.ASSIGNED_TICKET_CHANGED

    if alert_event == 'owned ticket changed':
        return AlertEvent.OWNED_TICKET_CHANGED

    raise InvalidArgument(
        argument='alert_event', function=get_alert_event_from_string.__name__
    )


class AlertCondition(Enum):
    """Enum for alert condition types """

    ALWAYS = 'Always'
    ERROR = 'Error'
    SEVERITY_AT_LEAST = 'Severity at least'
    SEVERITY_CHANGED = 'Severity changed'
    FILTER_COUNT_CHANGED = 'Filter count changed'
    FILTER_COUNT_AT_LEAST = 'Filter count at least'


def get_alert_condition_from_string(
    alert_condition: Optional[str],
) -> Optional[AlertCondition]:
    """Convert an alert condition string into a AlertCondition instance """
    if not alert_condition:
        return None

    alert_condition = alert_condition.lower()

    if alert_condition == 'error':
        return AlertCondition.ERROR

    if alert_condition == 'always':
        return AlertCondition.ALWAYS

    if alert_condition == 'filter count changed':
        return AlertCondition.FILTER_COUNT_CHANGED

    if alert_condition == 'filter count at least':
        return AlertCondition.FILTER_COUNT_AT_LEAST

    if alert_condition == 'severity at least':
        return AlertCondition.SEVERITY_AT_LEAST

    if alert_condition == 'severity changed':
        return AlertCondition.SEVERITY_CHANGED

    raise InvalidArgument(
        argument='alert_condition',
        function=get_alert_condition_from_string.__name__,
    )


class AlertMethod(Enum):
    """Enum for alert method type"""

    SCP = "SCP"
    SEND = "Send"
    SMB = "SMB"
    SNMP = "SNMP"
    SYSLOG = "Syslog"
    EMAIL = "Email"
    START_TASK = "Start Task"
    HTTP_GET = "HTTP Get"
    SOURCEFIRE_CONNECTOR = "Sourcefire Connector"
    VERINICE_CONNECTOR = "verinice Connector"
    TIPPINGPOINT = "TippingPoint SMS"
    ALEMBA_VFIRE = "Alemba vFire"


def get_alert_method_from_string(
    alert_method: Optional[str],
) -> Optional[AlertMethod]:
    """Convert an alert method string into a AlertCondition instance """
    if not alert_method:
        return None

    alert_method = alert_method.upper()

    if alert_method == 'START TASK':
        return AlertMethod.START_TASK

    if alert_method == 'HTTP GET':
        return AlertMethod.HTTP_GET

    if alert_method == 'SOURCEFIRE CONNECTOR':
        return AlertMethod.SOURCEFIRE_CONNECTOR

    if alert_method == 'VERINICE CONNECTOR':
        return AlertMethod.VERINICE_CONNECTOR

    if alert_method == 'TIPPINGPOINT SMS':
        return AlertMethod.TIPPINGPOINT

    if alert_method == 'ALEMBA VFIRE':
        return AlertMethod.ALEMBA_VFIRE

    try:
        return AlertMethod[alert_method]
    except KeyError:
        raise InvalidArgument(
            argument='alert_method',
            function=get_alert_method_from_string.__name__,
        ) from None


class FilterType(Enum):
    """Enum for filter types """

    AGENT = "agent"
    ALERT = "alert"
    ASSET = "asset"
    SCAN_CONFIG = "config"
    CREDENTIAL = "credential"
    FILTER = "filter"
    GROUP = "group"
    HOST = "host"
    NOTE = "note"
    OPERATING_SYSTEM = "os"
    OVERRIDE = "override"
    PERMISSION = "permission"
    PORT_LIST = "port_list"
    REPORT = "report"
    REPORT_FORMAT = "report_format"
    RESULT = "result"
    ROLE = "role"
    SCHEDULE = "schedule"
    ALL_SECINFO = "secinfo"
    TAG = "tag"
    TARGET = "target"
    TASK = "task"
    TICKET = "ticket"
    TLS_CERTIFICATE = "tls_certificate"
    USER = "user"
    VULNERABILITY = "vuln"


def get_filter_type_from_string(
    filter_type: Optional[str],
) -> Optional[FilterType]:
    """Convert a filter type string to an actual FilterType instance

    Arguments:
        filter_type (str): Filter type string to convert to a FilterType
    """
    if not filter_type:
        return None

    if filter_type == 'vuln':
        return FilterType.VULNERABILITY

    if filter_type == 'os':
        return FilterType.OPERATING_SYSTEM

    if filter_type == 'config':
        return FilterType.SCAN_CONFIG

    if filter_type == 'secinfo':
        return FilterType.ALL_SECINFO

    if filter_type == 'tls_certificate':
        return FilterType.TLS_CERTIFICATE

    try:
        return FilterType[filter_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='filter_type',
            function=get_filter_type_from_string.__name__,
        ) from None


class ScannerType(Enum):
    """ Enum for scanner type """

    OSP_SCANNER_TYPE = "1"
    OPENVAS_SCANNER_TYPE = "2"
    CVE_SCANNER_TYPE = "3"
    GMP_SCANNER_TYPE = "4"  # formerly slave scanner
    GREENBONE_SENSOR_SCANNER_TYPE = "5"


def get_scanner_type_from_string(
    scanner_type: Optional[str],
) -> Optional[ScannerType]:
    """Convert a scanner type string to an actual ScannerType instance

    Arguments:
        scanner_type: Scanner type string to convert to a ScannerType
    """
    if not scanner_type:
        return None

    scanner_type = scanner_type.lower()

    if (
        scanner_type == ScannerType.OSP_SCANNER_TYPE.value
        or scanner_type == 'osp'
    ):
        return ScannerType.OSP_SCANNER_TYPE

    if (
        scanner_type == ScannerType.OPENVAS_SCANNER_TYPE.value
        or scanner_type == 'openvas'
    ):
        return ScannerType.OPENVAS_SCANNER_TYPE

    if (
        scanner_type == ScannerType.CVE_SCANNER_TYPE.value
        or scanner_type == 'cve'
    ):
        return ScannerType.CVE_SCANNER_TYPE

    if (
        scanner_type == ScannerType.GMP_SCANNER_TYPE.value
        or scanner_type == 'gmp'
    ):
        return ScannerType.GMP_SCANNER_TYPE

    if (
        scanner_type == ScannerType.GREENBONE_SENSOR_SCANNER_TYPE.value
        or scanner_type == 'greenbone'
    ):
        return ScannerType.GREENBONE_SENSOR_SCANNER_TYPE

    raise InvalidArgument(
        argument='scanner_type', function=get_scanner_type_from_string.__name__
    )


class _UsageType(Enum):
    """Enum for usage types """

    AUDIT = "audit"
    POLICY = "policy"
    SCAN = "scan"


def __get_usage_type_from_string(
    usage_type: Optional[str],
) -> Optional[_UsageType]:
    """Convert a usage type string to an actual _UsageType instance

    Arguments:
        entity_type: Usage type string to convert to a _UsageType
    """
    if not usage_type:
        return None

    try:
        return _UsageType[usage_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='usage_type',
            function=__get_usage_type_from_string.__name__,
        ) from None



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgumentType


class GmpModifyConfigSetFamilySelectionTestCase:
    def test_modify_config_set_family_selection(self):
        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo']
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo', 'bar']
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '<family>'
            '<name>bar</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=('foo', 'bar')
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '<family>'
            '<name>bar</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

    def test_modify_config_set_family_selection_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_config_set_family_selection(
                config_id=None, families=['foo']
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_config_set_family_selection(
                config_id='', families=['foo']
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_config_set_family_selection('', ['foo'])

    def test_modify_config_set_family_selection_invalid_families(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_config_set_family_selection(
                config_id='c1', families=None
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_config_set_family_selection(
                config_id='c1', families=''
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_config_set_family_selection('c1', '')

    def test_modify_config_set_family_selection_with_auto_add_new_families(
        self,
    ):
        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo'], auto_add_new_families=True
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo'], auto_add_new_families=False
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>0</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

    def test_modify_config_set_family_selection_with_auto_add_new_nvts(self):
        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo'], auto_add_new_nvts=True
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>1</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )

        self.gmp.modify_config_set_family_selection(
            config_id='c1', families=['foo'], auto_add_new_nvts=False
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            '<family_selection>'
            '<growing>1</growing>'
            '<family>'
            '<name>foo</name>'
            '<all>1</all>'
            '<growing>0</growing>'
            '</family>'
            '</family_selection>'
            '</modify_config>'
        )


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgument, InvalidArgumentType

from gvm.protocols.gmpv7 import TimeUnit


class GmpModifyScheduleTestCase:
    def test_modify_schedule(self):
        self.gmp.modify_schedule(schedule_id='s1')

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1"/>'
        )

    def test_modify_schedule_missing_schedule_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(schedule_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(schedule_id='')

    def test_modify_schedule_with_comment(self):
        self.gmp.modify_schedule(schedule_id='s1', comment='foo')

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<comment>foo</comment>'
            '</modify_schedule>'
        )

    def test_create_schedule_with_first_time(self):
        self.gmp.modify_schedule(
            schedule_id='s1',
            first_time_minute=0,
            first_time_hour=0,
            first_time_day_of_month=1,
            first_time_month=1,
            first_time_year=2020,
        )

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<first_time>'
            '<minute>0</minute>'
            '<hour>0</hour>'
            '<day_of_month>1</day_of_month>'
            '<month>1</month>'
            '<year>2020</year>'
            '</first_time>'
            '</modify_schedule>'
        )

    def test_modify_schedule_with_first_time_missing_minute(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_hour=10,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_invalid_minute(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute='',
                first_time_hour=1,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=-1,
                first_time_hour=1,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_missing_hour(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=10,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_invalid_hour(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=10,
                first_time_hour='',
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=10,
                first_time_hour=-1,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_missing_day_of_month(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_invalid_day_of_month(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month='',
                first_time_month=1,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=0,
                first_time_month=1,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=-1,
                first_time_month=1,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=32,
                first_time_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_missing_month(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_invalid_month(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month='',
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=0,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=-1,
                first_time_year=2020,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=13,
                first_time_year=2020,
            )

    def test_modify_schedule_with_first_time_missing_year(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=12,
            )

    def test_modify_schedule_with_first_time_invalid_year(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=1,
                first_time_year=1,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1',
                first_time_minute=0,
                first_time_hour=0,
                first_time_day_of_month=1,
                first_time_month=0,
                first_time_year=2020,
            )

    def test_modify_schedule_with_name(self):
        self.gmp.modify_schedule(schedule_id='s1', name='foo')

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<name>foo</name>'
            '</modify_schedule>'
        )

    def test_modify_schedule_invalid_duration(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', duration='bar', duration_unit=TimeUnit.DAY
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', duration=0, duration_unit=TimeUnit.DAY
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', duration=-1, duration_unit=TimeUnit.DAY
            )

    def test_modify_schedule_with_duration_missing_unit(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(schedule_id='s1', duration=1)

    def test_modify_schedule_with_duration_invalid_unit(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_schedule(
                schedule_id='s1', duration=1, duration_unit='foo'
            )

    def test_modify_schedule_with_duration(self):
        self.gmp.modify_schedule(
            schedule_id='s1', duration=1, duration_unit=TimeUnit.DAY
        )

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<duration>1'
            '<unit>day</unit>'
            '</duration>'
            '</modify_schedule>'
        )

    def test_modify_schedule_with_period_missing_unit(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_schedule(schedule_id='s1', period=1)

    def test_modify_schedule_with_period_invalid_unit(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_schedule(
                schedule_id='s1', period=1, period_unit='foo'
            )

    def test_modify_schedule_invalid_period(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', period='foo', period_unit=TimeUnit.DAY
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', period=0, period_unit=TimeUnit.DAY
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_schedule(
                schedule_id='s1', period=-1, period_unit=TimeUnit.DAY
            )

    def test_modify_schedule_with_period(self):
        self.gmp.modify_schedule(
            schedule_id='s1', period=1, period_unit=TimeUnit.DAY
        )

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<period>1'
            '<unit>day</unit>'
            '</period>'
            '</modify_schedule>'
        )

    def test_modify_schedule_with_timezone(self):
        self.gmp.modify_schedule(schedule_id='s1', timezone='foo')

        self.connection.send.has_been_called_with(
            '<modify_schedule schedule_id="s1">'
            '<timezone>foo</timezone>'
            '</modify_schedule>'
        )


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv8TestCase
from ..gmpv7.testcmds import *  # pylint: disable=unused-wildcard-import,wildcard-import


class Gmpv8AuthenticateTestCase(GmpAuthenticateTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneAgentTestCase(GmpCloneAgentTestCase, Gmpv8TestCase):

    pass


class Gmpv8CloneAlertTestCase(GmpCloneAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneReportFormatTestCase(
    GmpCloneReportFormatTestCase, Gmpv8TestCase
):
    pass


class Gmpv8CloneCredentialTestCase(GmpCloneCredentialTestCase, Gmpv8TestCase):

    pass


class Gmpv8CloneFilterTestCase(GmpCloneFilterTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneGroupTestCase(GmpCloneGroupTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneNoteTestCase(GmpCloneNoteTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneOverrideTestCase(GmpCloneOverrideTestCase, Gmpv8TestCase):
    pass


class Gmpv8ClonePermissionTestCase(GmpClonePermissionTestCase, Gmpv8TestCase):
    pass


class Gmpv8ClonePortListTestCase(GmpClonePortListTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneRoleTestCase(GmpCloneRoleTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneScannerTestCase(GmpCloneScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneScheduleTestCase(GmpCloneScheduleTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneTagTestCase(GmpCloneTagTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneTargetCommandTestCase(
    GmpCloneTargetCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8CloneTaskTestCase(GmpCloneTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8CloneUserTestCase(GmpCloneUserTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateAgentTestCase(GmpCreateAgentTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateAlertTestCase(GmpCreateAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateContainerTaskCommandTestCase(
    GMPCreateContainerTaskCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8CreateGroupTestCase(GmpCreateGroupTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateHostTestCase(GmpCreateHostTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateNoteTestCase(GmpCreateNoteTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateOverrideTestCase(GmpCreateOverrideTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreatePortListTestCase(GmpCreatePortListTestCase, Gmpv8TestCase):
    pass


class Gmpv8HelpTestCase(GmpHelpTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreatePortRangeTestCase(GmpCreatePortRangeTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateRoleTestCase(GmpCreateRoleTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateScannerTestCase(GmpCreateScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateTaskCommandTestCase(
    GmpCreateTaskCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8CreateUserTestCase(GmpCreateUserTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteAgentTestCase(GmpDeleteAgentTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteAlertTestCase(GmpDeleteAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteAssetTestCase(GmpDeleteAssetTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteConfigTestCase(GmpDeleteConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteCredentialTestCase(GmpDeleteCredentialTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteFilterTestCase(GmpDeleteFilterTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteGroupTestCase(GmpDeleteGroupTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteNoteTestCase(GmpDeleteNoteTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteOverrideTestCase(GmpDeleteOverrideTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeletePermissionTestCase(GmpDeletePermissionTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeletePortListTestCase(GmpDeletePortListTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeletePortRangeTestCase(GmpDeletePortRangeTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteReportTestCase(GmpDeleteReportTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteReportFormatTestCase(
    GmpDeleteReportFormatTestCase, Gmpv8TestCase
):
    pass


class Gmpv8DeleteRoleTestCase(GmpDeleteRoleTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteScannerTestCase(GmpDeleteScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteScheduleTestCase(GmpDeleteScheduleTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteTagTestCase(GmpDeleteTagTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteTargetTestCase(GmpDeleteTargetTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteTaskTestCase(GmpDeleteTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteUserTestCase(GmpDeleteUserTestCase, Gmpv8TestCase):
    pass


class Gmpv8DescribeAuthCommandTestCase(
    GmpDescribeAuthCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8EmptyTrashcanCommandTestCase(
    GmpEmptyTrashcanCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8GetAgentTestCase(GmpGetAgentTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetAgentsTestCase(GmpGetAgentsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetAlertTestCase(GmpGetAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetAlertsTestCase(GmpGetAlertsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetAssetTestCase(GmpGetAssetTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetAssetsTestCase(GmpGetAssetsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetConfigTestCase(GmpGetConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetConfigsTestCase(GmpGetConfigsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetCredentialTestCase(GmpGetCredentialTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetCredentialsTestCase(GmpGetCredentialsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetFeedTestCase(GmpGetFeedTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetFeedsTestCase(GmpGetFeedsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetFilterTestCase(GmpGetFilterTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetFiltersTestCase(GmpGetFiltersTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetGroupTestCase(GmpGetGroupTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetGroupsTestCase(GmpGetGroupsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetInfoTestCase(GmpGetInfoTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetInfoListTestCase(GmpGetInfoListTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetNoteTestCase(GmpGetNoteTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetNotesTestCase(GmpGetNotesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetNvtTestCase(GmpGetNvtTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetNvtFamiliesTestCase(GmpGetNvtFamiliesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetNvtsTestCase(GmpGetNvtsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetOverrideTestCase(GmpGetOverrideTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetOverridesTestCase(GmpGetOverridesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPermissionTestCase(GmpGetPermissionTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPermissionsTestCase(GmpGetPermissionsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPortListTestCase(GmpGetPortListTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPortListsTestCase(GmpGetPortListsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPreferenceTestCase(GmpGetPreferenceTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetPreferencesTestCase(GmpGetPreferencesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetReportTestCase(GmpGetReportTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetReportFormatTestCase(GmpGetReportFormatTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetReportFormatsTestCase(GmpGetReportFormatsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetReportsTestCase(GmpGetReportsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetResultTestCase(GmpGetResultTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetResultsTestCase(GmpGetResultsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetRoleTestCase(GmpGetRoleTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetRolesTestCase(GmpGetRolesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetScannerTestCase(GmpGetScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetScannersTestCase(GmpGetScannersTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetScheduleTestCase(GmpGetScheduleTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetSchedulesTestCase(GmpGetSchedulesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetSettingTestCase(GmpGetSettingTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetSettingsTestCase(GmpGetSettingsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetSystemReportsTestCase(GmpGetSystemReportsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTagTestCase(GmpGetTagTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTagsTestCase(GmpGetTagsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTargetTestCase(GmpGetTargetTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTargetsTestCase(GmpGetTargetsTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTaskTestCase(GmpGetTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTasksTestCase(GmpGetTasksTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetUserTestCase(GmpGetUserTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetUsersTestCase(GmpGetUsersTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetVersionCommandTestCase(
    GmpGetVersionCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ImportConfigTestCase(GmpImportConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8ImportReportFormatTestCase(
    GmpImportReportFormatTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ImportReportTestCase(GmpImportReportTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyAgentTestCase(GmpModifyAgentTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyAlertTestCase(GmpModifyAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyAssetTestCase(GmpModifyAssetTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyAuthTestCase(GmpModifyAuthTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyConfigTestCase(GmpModifyConfigTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyConfigSetCommentTestCase(
    GmpModifyConfigSetCommentTestCase, Gmpv8TestCase
):
    pass


class Gmpv7ModifyConfigSetNameTestCase(
    GmpModifyConfigSetNameTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyConfigSetFamilySelectionTestCase(
    GmpModifyConfigSetFamilySelectionTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyConfigSetNvtPreferenceTestCase(
    GmpModifyConfigSetNvtPreferenceTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyConfigSetNvtSelectionTestCase(
    GmpModifyConfigSetNvtSelectionTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyConfigSetScannerPreferenceTestCase(
    GmpModifyConfigSetScannerPreferenceTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyGroupTestCase(GmpModifyGroupTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyNoteTestCase(GmpModifyNoteTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyOverrideTestCase(GmpModifyOverrideTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyPortListTestCase(GmpModifyPortListTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyRoleTestCase(GmpModifyRoleTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyScannerTestCase(GmpModifyScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifySettingTestCase(GmpModifySettingTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyTargetTestCase(GmpModifyTargetTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyTaskCommandTestCase(
    GmpModifyTaskCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyUserTestCase(GmpModifyUserTestCase, Gmpv8TestCase):
    pass


class Gmpv8MoveTaskTestCase(GmpMoveTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8RestoreTestCase(GmpRestoreTestCase, Gmpv8TestCase):
    pass


class Gmpv8ResumeTaskTestCase(GmpResumeTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8StartTaskTestCase(GmpStartTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8StopTaskTestCase(GmpStopTaskTestCase, Gmpv8TestCase):
    pass


class Gmpv8SyncCertCommandTestCase(GmpSyncCertCommandTestCase, Gmpv8TestCase):
    pass


class Gmpv8SyncConfigCommandTestCase(
    GmpSyncConfigCommandTestCase, Gmpv8TestCase
):

    pass


class Gmpv8SyncFeedCommandTestCase(GmpSyncFeedCommandTestCase, Gmpv8TestCase):
    pass


class Gmpv8SyncScapCommandTestCase(GmpSyncScapCommandTestCase, Gmpv8TestCase):
    pass


class Gmpv8TestAlertTestCase(GmpTestAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8TriggerAlertTestCase(GmpTriggerAlertTestCase, Gmpv8TestCase):
    pass


class Gmpv8VerifyAgentTestCase(GmpVerifyAgentTestCase, Gmpv8TestCase):
    pass


class Gmpv8VerifyReportFormatTestCase(
    GmpVerifyReportFormatTestCase, Gmpv8TestCase
):
    pass


class Gmpv8v7VerifyScannerTestCase(GmpVerifyScannerTestCase, Gmpv8TestCase):
    pass


class Gmpv8v7WithStatementTestCase(GmpWithStatementTestCase, Gmpv8TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv9TestCase
from .testcmds import *  # pylint: disable=wildcard-import


class Gmpv9CloneAuditTestCase(GmpCloneAuditTestCase, Gmpv9TestCase):
    pass


class Gmpv9CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv9TestCase):
    pass


class Gmpv9ClonePolicyTestCase(GmpClonePolicyTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyAlertTestCase(GmpModifyAlertTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreateAlertTestCase(GmpCreateAlertTestCase, Gmpv9TestCase):
    pass


class Gmpv9CloneTaskTestCase(GmpCloneTaskTestCase, Gmpv9TestCase):
    pass


class Gmpv9CloneTLSCertificateTestCase(
    GmpCloneTLSCertificateTestCase, Gmpv9TestCase
):
    pass


class Gmpv9CreateAuditCommandTestCase(
    GmpCreateAuditCommandTestCase, Gmpv9TestCase
):
    pass


class Gmpv9CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreateConfigFromOSPScannerTestCase(
    GmpCreateConfigFromOSPScannerTestCase, Gmpv9TestCase
):
    pass


class Gmpv9CreateCredentialTestCase(GmpCreateCredentialTestCase, Gmpv9TestCase):

    pass


class Gmpv9CreateFilterTestCase(GmpCreateFilterTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreatePermissionTestCase(GmpCreatePermissionTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreatePolicyTestCase(GmpCreatePolicyTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreateTagTestCase(GmpCreateTagTestCase, Gmpv9TestCase):
    pass


class Gmpv9CreateTaskCommandTestCase(
    GmpCreateTaskCommandTestCase, Gmpv9TestCase
):
    pass


class Gmpv9CreateTLSCertificateTestCase(
    GmpCreateTLSCertificateTestCase, Gmpv9TestCase
):
    pass


class Gmpv9DeleteAuditTestCase(GmpDeleteAuditTestCase, Gmpv9TestCase):
    pass


class Gmpv9DeleteConfigTestCase(GmpDeleteConfigTestCase, Gmpv9TestCase):

    pass


class Gmpv9DeletePolicyTestCase(GmpDeletePolicyTestCase, Gmpv9TestCase):
    pass


class Gmpv9DeleteTaskTestCase(GmpDeleteTaskTestCase, Gmpv9TestCase):
    pass


class Gmpv9DeleteTLSCertificateTestCase(
    GmpDeleteTLSCertificateTestCase, Gmpv9TestCase
):
    pass


class Gmpv9GetAggregatesTestCase(GmpGetAggregatesTestCase, Gmpv9TestCase):

    pass


class Gmpv9GetAuditTestCase(GmpGetAuditTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetAuditsTestCase(GmpGetAuditsTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetConfigTestCase(GmpGetConfigTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetConfigsTestCase(GmpGetConfigsTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetPoliciesTestCase(GmpGetPoliciesTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetPolicyTestCase(GmpGetPolicyTestCase, Gmpv9TestCase):

    pass


class Gmpv9GetTaskTestCase(GmpGetTaskTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetTasksTestCase(GmpGetTasksTestCase, Gmpv9TestCase):
    pass


class Gmpv9GetTlsCertificateTestCase(
    GmpGetTlsCertificateTestCase, Gmpv9TestCase
):
    pass


class Gmpv9GetTLSCertificatesTestCase(
    GmpGetTLSCertificatesTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyAuditCommandTestCase(
    GmpModifyAuditCommandTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyCredentialTestCase(GmpModifyCredentialTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyFilterTestCase(GmpModifyFilterTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyPermissionTestCase(GmpModifyPermissionTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyPolicySetCommentTestCase(
    GmpModifyPolicySetCommentTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyPolicySetNameTestCase(
    GmpModifyPolicySetNameTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyPolicySetFamilySelectionTestCase(
    GmpModifyPolicySetFamilySelectionTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyPolicySetNvtPreferenceTestCase(
    GmpModifyPolicySetNvtPreferenceTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyPolicySetNvtSelectionTestCase(
    GmpModifyPolicySetNvtSelectionTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyPolicySetScannerPreferenceTestCase(
    GmpModifyPolicySetScannerPreferenceTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyReportFormatTestCase(
    GmpModifyReportFormatTestCase, Gmpv9TestCase
):
    pass


class Gmpv9ModifyTagTestCase(GmpModifyTagTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyTicketTestCase(GmpModifyTicketTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyTLSCertificateTestCase(
    GmpModifyTLSCertificateTestCase, Gmpv9TestCase
):
    pass


class Gmpv9CreateScannerTestCase(GmpCreateScannerTestCase, Gmpv9TestCase):
    pass


class Gmpv9ModifyScannerTestCase(GmpModifyScannerTestCase, Gmpv9TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgumentType
from gvm.protocols.gmpv8 import FilterType


class GmpModifyFilterTestCase:
    def test_modify_filter(self):
        self.gmp.modify_filter(filter_id='f1')

        self.connection.send.has_been_called_with(
            '<modify_filter filter_id="f1"/>'
        )

    def test_modify_filter_with_filter_type(self):
        self.gmp.modify_filter(filter_id='f1', filter_type=FilterType.TASK)

        self.connection.send.has_been_called_with(
            '<modify_filter filter_id="f1">'
            '<type>task</type>'
            '</modify_filter>'
        )

    def test_modify_filter_invalid_filter_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_filter(filter_id='f1', filter_type='foo')

    def test_modify_filter_missing_filter_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_filter(filter_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_filter(filter_id='')

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_filter('')

    def test_modify_filter_with_comment(self):
        self.gmp.modify_filter(filter_id='f1', comment='foo')

        self.connection.send.has_been_called_with(
            '<modify_filter filter_id="f1">'
            '<comment>foo</comment>'
            '</modify_filter>'
        )

    def test_modify_filter_with_name(self):
        self.gmp.modify_filter(filter_id='f1', name='foo')

        self.connection.send.has_been_called_with(
            '<modify_filter filter_id="f1">'
            '<name>foo</name>'
            '</modify_filter>'
        )

    def test_modify_filter_with_term(self):
        self.gmp.modify_filter(filter_id='f1', term='foo=bar')

        self.connection.send.has_been_called_with(
            '<modify_filter filter_id="f1">'
            '<term>foo=bar</term>'
            '</modify_filter>'
        )


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv7TestCase
from .testcmds import *  # pylint: disable=wildcard-import


class Gmpv7AuthenticateTestCase(GmpAuthenticateTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneAgentTestCase(GmpCloneAgentTestCase, Gmpv7TestCase):

    pass


class Gmpv7CloneAlertTestCase(GmpCloneAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneReportFormatTestCase(
    GmpCloneReportFormatTestCase, Gmpv7TestCase
):
    pass


class Gmpv7CloneCredentialTestCase(GmpCloneCredentialTestCase, Gmpv7TestCase):

    pass


class Gmpv7CloneFilterTestCase(GmpCloneFilterTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneGroupTestCase(GmpCloneGroupTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneNoteTestCase(GmpCloneNoteTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneOverrideTestCase(GmpCloneOverrideTestCase, Gmpv7TestCase):
    pass


class Gmpv7ClonePermissionTestCase(GmpClonePermissionTestCase, Gmpv7TestCase):
    pass


class Gmpv7ClonePortListTestCase(GmpClonePortListTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneRoleTestCase(GmpCloneRoleTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneScannerTestCase(GmpCloneScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneScheduleTestCase(GmpCloneScheduleTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneTagTestCase(GmpCloneTagTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneTargetCommandTestCase(
    GmpCloneTargetCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7HelpTestCase(GmpHelpTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneTaskTestCase(GmpCloneTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7CloneUserTestCase(GmpCloneUserTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateAgentTestCase(GmpCreateAgentTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateAlertTestCase(GmpCreateAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateContainerTaskCommandTestCase(
    GMPCreateContainerTaskCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7CreateCredentialTestCase(GmpCreateCredentialTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateFilterCommandTestCase(
    GmpCreateFilterCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7CreateGroupTestCase(GmpCreateGroupTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateHostTestCase(GmpCreateHostTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateNoteTestCase(GmpCreateNoteTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateOverrideTestCase(GmpCreateOverrideTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreatePermissionTestCase(GmpCreatePermissionTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreatePortListTestCase(GmpCreatePortListTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreatePortRangeTestCase(GmpCreatePortRangeTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateRoleTestCase(GmpCreateRoleTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateScannerTestCase(GmpCreateScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateScheduleTestCase(GmpCreateScheduleTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateTagTestCase(GmpCreateTagTestCase, Gmpv7TestCase):
    pass


class Gmpv7CreateTargetCommandTestCase(
    GmpCreateTargetCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7CreateTaskCommandTestCase(
    GmpCreateTaskCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7CreateUserTestCase(GmpCreateUserTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteAgentTestCase(GmpDeleteAgentTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteAlertTestCase(GmpDeleteAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteAssetTestCase(GmpDeleteAssetTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteConfigTestCase(GmpDeleteConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteCredentialTestCase(GmpDeleteCredentialTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteFilterTestCase(GmpDeleteFilterTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteGroupTestCase(GmpDeleteGroupTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteNoteTestCase(GmpDeleteNoteTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteOverrideTestCase(GmpDeleteOverrideTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeletePermissionTestCase(GmpDeletePermissionTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeletePortListTestCase(GmpDeletePortListTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeletePortRangeTestCase(GmpDeletePortRangeTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteReportTestCase(GmpDeleteReportTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteReportFormatTestCase(
    GmpDeleteReportFormatTestCase, Gmpv7TestCase
):
    pass


class Gmpv7DeleteRoleTestCase(GmpDeleteRoleTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteScannerTestCase(GmpDeleteScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteScheduleTestCase(GmpDeleteScheduleTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteTagTestCase(GmpDeleteTagTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteTargetTestCase(GmpDeleteTargetTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteTaskTestCase(GmpDeleteTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7DeleteUserTestCase(GmpDeleteUserTestCase, Gmpv7TestCase):
    pass


class Gmpv7DescribeAuthCommandTestCase(
    GmpDescribeAuthCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7EmptyTrashcanCommandTestCase(
    GmpEmptyTrashcanCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7GetAgentTestCase(GmpGetAgentTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAgentsTestCase(GmpGetAgentsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAggregatesTestCase(GmpGetAggregatesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAlertTestCase(GmpGetAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAlertsTestCase(GmpGetAlertsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAssetTestCase(GmpGetAssetTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetAssetsTestCase(GmpGetAssetsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetConfigTestCase(GmpGetConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetConfigsTestCase(GmpGetConfigsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetCredentialTestCase(GmpGetCredentialTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetCredentialsTestCase(GmpGetCredentialsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetFeedTestCase(GmpGetFeedTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetFeedsTestCase(GmpGetFeedsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetFilterTestCase(GmpGetFilterTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetFiltersTestCase(GmpGetFiltersTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetGroupTestCase(GmpGetGroupTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetGroupsTestCase(GmpGetGroupsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetInfoTestCase(GmpGetInfoTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetInfoListTestCase(GmpGetInfoListTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetNoteTestCase(GmpGetNoteTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetNotesTestCase(GmpGetNotesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetNvtTestCase(GmpGetNvtTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetNvtFamiliesTestCase(GmpGetNvtFamiliesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetNvtsTestCase(GmpGetNvtsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetOverrideTestCase(GmpGetOverrideTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetOverridesTestCase(GmpGetOverridesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPermissionTestCase(GmpGetPermissionTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPermissionsTestCase(GmpGetPermissionsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPortListTestCase(GmpGetPortListTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPortListsTestCase(GmpGetPortListsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPreferenceTestCase(GmpGetPreferenceTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetPreferencesTestCase(GmpGetPreferencesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetReportTestCase(GmpGetReportTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetReportFormatTestCase(GmpGetReportFormatTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetReportFormatsTestCase(GmpGetReportFormatsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetReportsTestCase(GmpGetReportsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetResultTestCase(GmpGetResultTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetResultsTestCase(GmpGetResultsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetRoleTestCase(GmpGetRoleTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetRolesTestCase(GmpGetRolesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetScannerTestCase(GmpGetScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetScannersTestCase(GmpGetScannersTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetScheduleTestCase(GmpGetScheduleTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetSchedulesTestCase(GmpGetSchedulesTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetSettingTestCase(GmpGetSettingTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetSettingsTestCase(GmpGetSettingsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetSystemReportsTestCase(GmpGetSystemReportsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTagTestCase(GmpGetTagTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTagsTestCase(GmpGetTagsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTargetTestCase(GmpGetTargetTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTargetsTestCase(GmpGetTargetsTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTaskTestCase(GmpGetTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetTasksTestCase(GmpGetTasksTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetUserTestCase(GmpGetUserTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetUsersTestCase(GmpGetUsersTestCase, Gmpv7TestCase):
    pass


class Gmpv7GetVersionCommandTestCase(
    GmpGetVersionCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ImportConfigTestCase(GmpImportConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7ImportReportFormatTestCase(
    GmpImportReportFormatTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ImportReportTestCase(GmpImportReportTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyAgentTestCase(GmpModifyAgentTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyAlertTestCase(GmpModifyAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyAssetTestCase(GmpModifyAssetTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyAuthTestCase(GmpModifyAuthTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyConfigTestCase(GmpModifyConfigTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyConfigSetCommentTestCase(
    GmpModifyConfigSetCommentTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyConfigSetNameTestCase(
    GmpModifyConfigSetNameTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyConfigSetFamilySelectionTestCase(
    GmpModifyConfigSetFamilySelectionTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyConfigSetNvtPreferenceTestCase(
    GmpModifyConfigSetNvtPreferenceTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyConfigSetNvtSelectionTestCase(
    GmpModifyConfigSetNvtSelectionTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyConfigSetScannerPreferenceTestCase(
    GmpModifyConfigSetScannerPreferenceTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyCredentialTestCase(GmpModifyCredentialTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyFilterTestCase(GmpModifyFilterTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyGroupTestCase(GmpModifyGroupTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyNoteTestCase(GmpModifyNoteTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyOverrideTestCase(GmpModifyOverrideTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyPermissionTestCase(GmpModifyPermissionTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyPortListTestCase(GmpModifyPortListTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyReportFormatTestCase(
    GmpModifyReportFormatTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyRoleTestCase(GmpModifyRoleTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyScannerTestCase(GmpModifyScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyScheduleTestCase(GmpModifyScheduleTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifySettingTestCase(GmpModifySettingTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyTagTestCase(GmpModifyTagTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyTargetTestCase(GmpModifyTargetTestCase, Gmpv7TestCase):
    pass


class Gmpv7ModifyTaskCommandTestCase(
    GmpModifyTaskCommandTestCase, Gmpv7TestCase
):
    pass


class Gmpv7ModifyUserTestCase(GmpModifyUserTestCase, Gmpv7TestCase):
    pass


class Gmpv7MoveTaskTestCase(GmpMoveTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7ProtocolVersionTestCase(GmpProtocolVersionTestCase, Gmpv7TestCase):
    pass


class Gmpv7RestoreTestCase(GmpRestoreTestCase, Gmpv7TestCase):
    pass


class Gmpv7ResumeTaskTestCase(GmpResumeTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7StartTaskTestCase(GmpStartTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7StopTaskTestCase(GmpStopTaskTestCase, Gmpv7TestCase):
    pass


class Gmpv7SyncCertCommandTestCase(GmpSyncCertCommandTestCase, Gmpv7TestCase):
    pass


class Gmpv7SyncConfigCommandTestCase(
    GmpSyncConfigCommandTestCase, Gmpv7TestCase
):

    pass


class Gmpv7SyncFeedCommandTestCase(GmpSyncFeedCommandTestCase, Gmpv7TestCase):
    pass


class Gmpv7SyncScapCommandTestCase(GmpSyncScapCommandTestCase, Gmpv7TestCase):
    pass


class Gmpv7TestAlertTestCase(GmpTestAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7TriggerAlertTestCase(GmpTriggerAlertTestCase, Gmpv7TestCase):
    pass


class Gmpv7VerifyAgentTestCase(GmpVerifyAgentTestCase, Gmpv7TestCase):
    pass


class Gmpv7VerifyReportFormatTestCase(
    GmpVerifyReportFormatTestCase, Gmpv7TestCase
):
    pass


class Gmpv7v7VerifyScannerTestCase(GmpVerifyScannerTestCase, Gmpv7TestCase):
    pass


class Gmpv7v7WithStatementTestCase(GmpWithStatementTestCase, Gmpv7TestCase):
    pass



# -*- coding utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier GPL-3.0-or-later
#
# This program is free software you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http//www.gnu.org/licenses/>.

# pylint: disable=no-member

from .test_clone_ticket import GmpCloneTicketTestCase
from .test_create_credential import GmpCreateCredentialTestCase
from .test_create_filter import GmpCreateFilterTestCase
from .test_create_permission import GmpCreatePermissionTestCase
from .test_create_schedule import GmpCreateScheduleTestCase
from .test_create_tag import GmpCreateTagTestCase
from .test_create_target import GmpCreateTargetCommandTestCase
from .test_create_ticket import GmpCreateTicketTestCase
from .test_delete_ticket import GmpDeleteTicketTestCase
from .test_get_aggregates import GmpGetAggregatesTestCase
from .test_get_ticket import GmpGetTicketTestCase
from .test_get_tickets import GmpGetTargetsTestCase
from .test_get_vulnerabilities import GmpGetVulnerabilitiesTestCase
from .test_get_vulnerability import GmpGetVulnerabilityTestCase
from .test_modify_credential import GmpModifyTestCase
from .test_modify_filter import GmpModifyFilterTestCase
from .test_modify_permission import GmpModifyPermissionTestCase
from .test_modify_schedule import GmpModifyScheduleTestCase
from .test_modify_report_format import GmpModifyReportFormatTestCase
from .test_modify_tag import GmpModifyTagTestCase
from .test_modify_ticket import GmpModifyTicketTestCase
from .test_protocol_version import GmpProtocolVersionTestCase



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
from enum import Enum

from typing import Optional

from gvm.errors import InvalidArgument

from gvm.protocols.gmpv7.types import (
    AlertCondition,
    AlertEvent,
    AlertMethod,
    AliveTest,
    AssetType,
    CredentialFormat,
    FeedType,
    HostsOrdering,
    InfoType,
    PermissionSubjectType,
    PortRangeType,
    ReportFormatType,
    ScannerType,
    SeverityLevel,
    SnmpAuthAlgorithm,
    SnmpPrivacyAlgorithm,
    TimeUnit,
    get_alert_condition_from_string,
    get_alert_event_from_string,
    get_alert_method_from_string,
    get_alive_test_from_string,
    get_asset_type_from_string,
    get_credential_format_from_string,
    get_feed_type_from_string,
    get_hosts_ordering_from_string,
    get_info_type_from_string,
    get_permission_subject_type_from_string,
    get_port_range_type_from_string,
    get_report_format_id_from_string,
    get_severity_level_from_string,
    get_scanner_type_from_string,
    get_snmp_auth_algorithm_from_string,
    get_snmp_privacy_algorithm_from_string,
    get_time_unit_from_string,
)


__all__ = [
    "AlertCondition",
    "AlertEvent",
    "AlertMethod",
    "AliveTest",
    "AssetType",
    "CredentialFormat",
    "CredentialType",
    "EntityType",
    "FeedType",
    "FilterType",
    "HostsOrdering",
    "InfoType",
    "PermissionSubjectType",
    "PortRangeType",
    "ReportFormatType",
    "ScannerType",
    "SeverityLevel",
    "SnmpAuthAlgorithm",
    "SnmpPrivacyAlgorithm",
    "TicketStatus",
    "TimeUnit",
    "get_alert_condition_from_string",
    "get_alert_event_from_string",
    "get_alert_method_from_string",
    "get_alive_test_from_string",
    "get_asset_type_from_string",
    "get_credential_format_from_string",
    "get_credential_type_from_string",
    "get_entity_type_from_string",
    "get_feed_type_from_string",
    "get_filter_type_from_string",
    "get_hosts_ordering_from_string",
    "get_info_type_from_string",
    "get_permission_subject_type_from_string",
    "get_port_range_type_from_string",
    "get_report_format_id_from_string",
    "get_scanner_type_from_string",
    "get_severity_level_from_string",
    "get_snmp_auth_algorithm_from_string",
    "get_snmp_privacy_algorithm_from_string",
    "get_ticket_status_from_string",
    "get_time_unit_from_string",
]


class EntityType(Enum):
    """Enum for entity types """

    AGENT = "agent"
    ALERT = "alert"
    ASSET = "asset"
    CERT_BUND_ADV = "cert_bund_adv"
    CPE = "cpe"
    CREDENTIAL = "credential"
    CVE = "cve"
    DFN_CERT_ADV = "dfn_cert_adv"
    FILTER = "filter"
    GROUP = "group"
    HOST = "host"
    INFO = "info"
    NOTE = "note"
    NVT = "nvt"
    OPERATING_SYSTEM = "os"
    OVALDEF = "ovaldef"
    OVERRIDE = "override"
    PERMISSION = "permission"
    PORT_LIST = "port_list"
    REPORT = "report"
    REPORT_FORMAT = "report_format"
    RESULT = "result"
    ROLE = "role"
    SCAN_CONFIG = "config"
    SCANNER = "scanner"
    SCHEDULE = "schedule"
    TAG = "tag"
    TARGET = "target"
    TASK = "task"
    USER = "user"

    TICKET = "ticket"
    VULNERABILITY = "vuln"


def get_entity_type_from_string(
    entity_type: Optional[str],
) -> Optional[EntityType]:
    """Convert a entity type string to an actual EntityType instance

    Arguments:
        entity_type: Entity type string to convert to a EntityType
    """
    if not entity_type:
        return None

    if entity_type == 'vuln':
        return EntityType.VULNERABILITY

    if entity_type == 'os':
        return EntityType.OPERATING_SYSTEM

    if entity_type == 'config':
        return EntityType.SCAN_CONFIG

    try:
        return EntityType[entity_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='entity_type',
            function=get_entity_type_from_string.__name__,
        ) from None


class FilterType(Enum):
    """Enum for filter types """

    AGENT = "agent"
    ALERT = "alert"
    ASSET = "asset"
    SCAN_CONFIG = "config"
    CREDENTIAL = "credential"
    FILTER = "filter"
    GROUP = "group"
    HOST = "host"
    NOTE = "note"
    OPERATING_SYSTEM = "os"
    OVERRIDE = "override"
    PERMISSION = "permission"
    PORT_LIST = "port_list"
    REPORT = "report"
    REPORT_FORMAT = "report_format"
    RESULT = "result"
    ROLE = "role"
    SCHEDULE = "schedule"
    ALL_SECINFO = "secinfo"
    TAG = "tag"
    TARGET = "target"
    TASK = "task"
    TICKET = "ticket"
    USER = "user"
    VULNERABILITY = "vuln"


def get_filter_type_from_string(
    filter_type: Optional[str],
) -> Optional[FilterType]:
    """Convert a filter type string to an actual FilterType instance

    Arguments:
        filter_type (str): Filter type string to convert to a FilterType
    """
    if not filter_type:
        return None

    if filter_type == 'vuln':
        return FilterType.VULNERABILITY

    if filter_type == 'os':
        return FilterType.OPERATING_SYSTEM

    if filter_type == 'config':
        return FilterType.SCAN_CONFIG

    if filter_type == 'secinfo':
        return FilterType.ALL_SECINFO

    try:
        return FilterType[filter_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='filter_type',
            function=get_filter_type_from_string.__name__,
        ) from None


class CredentialType(Enum):
    """ Enum for credential types """

    CLIENT_CERTIFICATE = 'cc'
    SNMP = 'snmp'
    USERNAME_PASSWORD = 'up'
    USERNAME_SSH_KEY = 'usk'
    SMIME_CERTIFICATE = 'smime'
    PGP_ENCRYPTION_KEY = 'pgp'
    PASSWORD_ONLY = 'pw'


def get_credential_type_from_string(
    credential_type: Optional[str],
) -> Optional[CredentialType]:
    """Convert a credential type string into a CredentialType instance"""
    if not credential_type:
        return None

    try:
        return CredentialType[credential_type.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='credential_type',
            function=get_credential_type_from_string.__name__,
        ) from None


class TicketStatus(Enum):
    """Enum for ticket status """

    OPEN = 'Open'
    FIXED = 'Fixed'
    CLOSED = 'Closed'


def get_ticket_status_from_string(
    ticket_status: Optional[str],
) -> Optional[TicketStatus]:
    """Convert a ticket status string into a TicketStatus instance"""
    if not ticket_status:
        return None

    try:
        return TicketStatus[ticket_status.upper()]
    except KeyError:
        raise InvalidArgument(
            argument='ticket_status',
            function=get_ticket_status_from_string.__name__,
        ) from None



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgument


class GmpImportReportTestCase:

    TASK_ID = '00000000-0000-0000-0000-000000000001'
    TASK_NAME = 'unit test task'
    COMMENT = 'This is a comment'
    REPORT_XML_STRING = (
        '<report id="67a62fb7-b238-4f0e-bc48-59bde8939cdc">'
        '<results max="1" start="1">'
        '<result id="f180b40f-49dd-4856-81ed-8c1195afce80">'
        '<severity>0.0</severity>'
        '<nvt oid="1.3.6.1.4.1.25623.1.0.10330"/>'
        '<host>132.67.253.114</host>'
        '</result></results></report>'
    )

    def test_import_report_with_task_id(self):
        self.gmp.import_report(self.REPORT_XML_STRING, task_id=self.TASK_ID)

        self.connection.send.has_been_called_with(
            '<create_report>'
            '<task id="{task}"/>'
            '{report}'
            '</create_report>'.format(
                task=self.TASK_ID, report=self.REPORT_XML_STRING
            )
        )

    def test_import_report_with_task_name(self):
        self.gmp.import_report(
            self.REPORT_XML_STRING,
            task_name=self.TASK_NAME,
            task_comment=self.COMMENT,
        )

        self.connection.send.has_been_called_with(
            '<create_report>'
            '<task>'
            '<name>{task}</name>'
            '<comment>{comment}</comment>'
            '</task>'
            '{report}'
            '</create_report>'.format(
                task=self.TASK_NAME,
                comment=self.COMMENT,
                report=self.REPORT_XML_STRING,
            )
        )

    def test_import_report_missing_report(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.import_report(
                None, task_name=self.TASK_NAME, task_comment=self.COMMENT
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.import_report(
                '', task_name=self.TASK_NAME, task_comment=self.COMMENT
            )

    def test_import_report_missing_task(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.import_report(self.REPORT_XML_STRING)

    def test_import_report_invalid_xml(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.import_report(
                'Foo',  # not root tag
                task_name=self.TASK_NAME,
                task_comment=self.COMMENT,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.import_report(
                '<Foo>',  # missing closing tag
                task_name=self.TASK_NAME,
                task_comment=self.COMMENT,
            )

    def test_import_report_with_in_assets(self):
        self.gmp.import_report(
            self.REPORT_XML_STRING, task_name=self.TASK_NAME, in_assets=False
        )

        self.connection.send.has_been_called_with(
            '<create_report>'
            '<task>'
            '<name>{task}</name>'
            '</task>'
            '<in_assets>0</in_assets>'
            '{report}'
            '</create_report>'.format(
                task=self.TASK_NAME, report=self.REPORT_XML_STRING
            )
        )

        self.gmp.import_report(
            self.REPORT_XML_STRING, task_name=self.TASK_NAME, in_assets=True
        )

        self.connection.send.has_been_called_with(
            '<create_report>'
            '<task>'
            '<name>{task}</name>'
            '</task>'
            '<in_assets>1</in_assets>'
            '{report}'
            '</create_report>'.format(
                task=self.TASK_NAME, report=self.REPORT_XML_STRING
            )
        )


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest


class GmpSyncConfigCommandTestCase:
    def test_sync_config(self):
        self.gmp.sync_config()

        self.connection.send.has_been_called_with('<sync_config/>')


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv208TestCase
from ..gmpv8.testcmds import *  # pylint: disable=unused-wildcard-import,wildcard-import


class Gmpv208CloneTicketTestCase(GmpCloneTicketTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateCredentialTestCase(
    GmpCreateCredentialTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateScheduleTestCase(GmpCreateScheduleTestCase, Gmpv208TestCase):

    pass


class Gmpv208CreateTicketTestCase(GmpCreateTicketTestCase, Gmpv208TestCase):
    pass


class Gmpv208DeleteTicketTestCase(GmpDeleteTicketTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetTicketTestCase(GmpGetTicketTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetTargetsTestCase(GmpGetTargetsTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetVulnerabilitiesTestCase(
    GmpGetVulnerabilitiesTestCase, Gmpv208TestCase
):
    pass


class Gmpv208GetVulnerabilityTestCase(
    GmpGetVulnerabilityTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyTestCase(GmpModifyTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyScheduleTestCase(GmpModifyScheduleTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyTicketTestCase(GmpModifyTicketTestCase, Gmpv208TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from . import Gmpv208TestCase
from ..gmpv9.testcmds import *  # pylint: disable=unused-wildcard-import,wildcard-import


class Gmpv208CloneAuditTestCase(GmpCloneAuditTestCase, Gmpv208TestCase):
    pass


class Gmpv208CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv208TestCase):
    pass


class Gmpv208ClonePolicyTestCase(GmpClonePolicyTestCase, Gmpv208TestCase):

    pass


class Gmpv208CloneTaskTestCase(GmpCloneTaskTestCase, Gmpv208TestCase):
    pass


class Gmpv208CloneTLSCertificateTestCase(
    GmpCloneTLSCertificateTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateAuditCommandTestCase(
    GmpCreateAuditCommandTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateConfigFromOSPScannerTestCase(
    GmpCreateConfigFromOSPScannerTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateCredentialTestCase(
    GmpCreateCredentialTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreatePolicyTestCase(GmpCreatePolicyTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateTaskCommandTestCase(
    GmpCreateTaskCommandTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyAlertTestCase(GmpModifyAlertTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateAlertTestCase(GmpCreateAlertTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateTLSCertificateTestCase(
    GmpCreateTLSCertificateTestCase, Gmpv208TestCase
):

    pass


class Gmpv208DeleteAuditTestCase(GmpDeleteAuditTestCase, Gmpv208TestCase):
    pass


class Gmpv208DeleteConfigTestCase(GmpDeleteConfigTestCase, Gmpv208TestCase):
    pass


class Gmpv208DeletePolicyTestCase(GmpDeletePolicyTestCase, Gmpv208TestCase):

    pass


class Gmpv208DeleteTaskTestCase(GmpDeleteTaskTestCase, Gmpv208TestCase):
    pass


class Gmpv208DeleteTLSCertificateTestCase(
    GmpDeleteTLSCertificateTestCase, Gmpv208TestCase
):
    pass


class Gmpv208GetAuditTestCase(GmpGetAuditTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetAuditsTestCase(GmpGetAuditsTestCase, Gmpv208TestCase):

    pass


class Gmpv208GetConfigTestCase(GmpGetConfigTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetConfigsTestCase(GmpGetConfigsTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetPoliciesTestCase(GmpGetPoliciesTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetPolicyTestCase(GmpGetPolicyTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetTaskTestCase(GmpGetTaskTestCase, Gmpv208TestCase):
    pass


class Gmpv208GetTasksTestCase(GmpGetTasksTestCase, Gmpv208TestCase):

    pass


class Gmpv208GetTlsCertificateTestCase(
    GmpGetTlsCertificateTestCase, Gmpv208TestCase
):
    pass


class Gmpv208GetTLSCertificatesTestCase(
    GmpGetTLSCertificatesTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyAuditCommandTestCase(
    GmpModifyAuditCommandTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyCredentialTestCase(
    GmpModifyCredentialTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetCommentTestCase(
    GmpModifyPolicySetCommentTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetNameTestCase(
    GmpModifyPolicySetNameTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetFamilySelectionTestCase(
    GmpModifyPolicySetFamilySelectionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetNvtPreferenceTestCase(
    GmpModifyPolicySetNvtPreferenceTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetNvtSelectionTestCase(
    GmpModifyPolicySetNvtSelectionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyPolicySetScannerPreferenceTestCase(
    GmpModifyPolicySetScannerPreferenceTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyTicketTestCase(GmpModifyTicketTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyTLSCertificateTestCase(
    GmpModifyTLSCertificateTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateScannerTestCase(GmpCreateScannerTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyScannerTestCase(GmpModifyScannerTestCase, Gmpv208TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import RequiredArgument, InvalidArgumentType

from gvm.protocols.gmpv7 import AssetType


class GmpGetAssetTestCase:
    def test_get_asset_host(self):
        self.gmp.get_asset('a1', AssetType.HOST)

        self.connection.send.has_been_called_with(
            '<get_assets asset_id="a1" type="host"/>'
        )

        self.gmp.get_asset(asset_id='a1', asset_type=AssetType.HOST)

        self.connection.send.has_been_called_with(
            '<get_assets asset_id="a1" type="host"/>'
        )

    def test_get_asset_os(self):
        self.gmp.get_asset('a1', AssetType.OPERATING_SYSTEM)

        self.connection.send.has_been_called_with(
            '<get_assets asset_id="a1" type="os"/>'
        )
        self.gmp.get_asset(asset_id='a1', asset_type=AssetType.OPERATING_SYSTEM)

        self.connection.send.has_been_called_with(
            '<get_assets asset_id="a1" type="os"/>'
        )

    def test_get_asset_missing_asset_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_asset(
                asset_id=None, asset_type=AssetType.OPERATING_SYSTEM
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.get_asset(
                asset_id='', asset_type=AssetType.OPERATING_SYSTEM
            )

    def test_get_asset_invalid_asset_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.get_asset(asset_id='a1', asset_type='foo')

        with self.assertRaises(InvalidArgumentType):
            self.gmp.get_asset(asset_id='a1', asset_type=None)

        with self.assertRaises(InvalidArgumentType):
            self.gmp.get_asset(asset_id='a1', asset_type='')


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv208TestCase
from .testcmds import *  # pylint: disable=wildcard-import


class Gmpv208CloneAgentTestCase(GmpCloneAgentTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateFilterTestCase(GmpCreateFilterTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreatePermissionTestCase(
    GmpCreatePermissionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateTagTestCase(GmpCreateTagTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateTargetCommandTestCase(
    GmpCreateTargetCommandTestCase, Gmpv208TestCase
):
    pass


class Gmpv208GetAggregatesTestCase(GmpGetAggregatesTestCase, Gmpv208TestCase):

    pass


class Gmpv208GetInfoTestCase(GmpGetInfoTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyFilterTestCase(GmpModifyFilterTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyPermissionTestCase(
    GmpModifyPermissionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyReportFormatTestCase(
    GmpModifyReportFormatTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyTagTestCase(GmpModifyTagTestCase, Gmpv208TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2018 - 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# pylint: disable=too-many-lines,redefined-builtin
"""
Module for communication with gvmd in `Greenbone Management Protocol version 9`_

.. _Greenbone Management Protocol version 9:
    https://docs.greenbone.net/API/GMP/gmp-9.0.html
"""

from typing import Any, Callable, Optional

from gvm.protocols.gmpv9.gmpv9 import GmpV9Mixin
from gvm.protocols.gmpv8.gmpv8 import GmpV8Mixin
from gvm.protocols.gmpv7.gmpv7 import GmpV7Mixin
from gvm.connections import GvmConnection


from . import types
from .types import _UsageType as UsageType
from .types import *  # pylint: disable=unused-wildcard-import, wildcard-import

PROTOCOL_VERSION = (9,)


class Gmp(GmpV9Mixin, GmpV8Mixin, GmpV7Mixin):

    types = types

    def __init__(
        self,
        connection: GvmConnection,
        *,
        transform: Optional[Callable[[str], Any]] = None
    ):
        super().__init__(connection, transform=transform)

        # Is authenticated on gvmd
        self._authenticated = False

    @staticmethod
    def get_protocol_version() -> tuple:
        """Determine the Greenbone Management Protocol version.

        Returns:
            tuple: Implemented version of the Greenbone Management Protocol
        """
        return PROTOCOL_VERSION



# -*- coding utf-8 -*-
# Ctestright  2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier GPL-3.0-or-later
#
# This program is free software you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
#  any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http//www.gnu.org/licenses/>.

# pylint: disable=no-member

from .test_authenticate import GmpAuthenticateTestCase
from .test_clone_agent import GmpCloneAgentTestCase
from .test_clone_alert import GmpCloneAlertTestCase
from .test_clone_config import GmpCloneConfigTestCase
from .test_clone_report_format import GmpCloneReportFormatTestCase
from .test_clone_credential import GmpCloneCredentialTestCase
from .test_clone_filter import GmpCloneFilterTestCase
from .test_clone_group import GmpCloneGroupTestCase
from .test_clone_note import GmpCloneNoteTestCase
from .test_clone_override import GmpCloneOverrideTestCase
from .test_clone_permission import GmpClonePermissionTestCase
from .test_clone_port_list import GmpClonePortListTestCase
from .test_clone_role import GmpCloneRoleTestCase
from .test_clone_scanner import GmpCloneScannerTestCase
from .test_clone_schedule import GmpCloneScheduleTestCase
from .test_clone_tag import GmpCloneTagTestCase
from .test_clone_target import GmpCloneTargetCommandTestCase
from .test_clone_task import GmpCloneTaskTestCase
from .test_clone_user import GmpCloneUserTestCase
from .test_create_agent import GmpCreateAgentTestCase
from .test_create_alert import GmpCreateAlertTestCase
from .test_create_config import GmpCreateConfigTestCase
from .test_create_container_task import GMPCreateContainerTaskCommandTestCase
from .test_create_credential import GmpCreateCredentialTestCase
from .test_create_filter import GmpCreateFilterCommandTestCase
from .test_create_group import GmpCreateGroupTestCase
from .test_create_host import GmpCreateHostTestCase
from .test_create_note import GmpCreateNoteTestCase
from .test_create_override import GmpCreateOverrideTestCase
from .test_create_permission import GmpCreatePermissionTestCase
from .test_create_port_list import GmpCreatePortListTestCase
from .test_create_port_range import GmpCreatePortRangeTestCase
from .test_create_role import GmpCreateRoleTestCase
from .test_create_scanner import GmpCreateScannerTestCase
from .test_create_schedule import GmpCreateScheduleTestCase
from .test_create_tag import GmpCreateTagTestCase
from .test_create_target import GmpCreateTargetCommandTestCase
from .test_create_task import GmpCreateTaskCommandTestCase
from .test_create_user import GmpCreateUserTestCase
from .test_delete_agent import GmpDeleteAgentTestCase
from .test_delete_alert import GmpDeleteAlertTestCase
from .test_delete_asset import GmpDeleteAssetTestCase
from .test_delete_config import GmpDeleteConfigTestCase
from .test_delete_credential import GmpDeleteCredentialTestCase
from .test_delete_filter import GmpDeleteFilterTestCase
from .test_delete_group import GmpDeleteGroupTestCase
from .test_delete_note import GmpDeleteNoteTestCase
from .test_delete_override import GmpDeleteOverrideTestCase
from .test_delete_permission import GmpDeletePermissionTestCase
from .test_delete_port_list import GmpDeletePortListTestCase
from .test_delete_port_range import GmpDeletePortRangeTestCase
from .test_delete_report import GmpDeleteReportTestCase
from .test_delete_report_format import GmpDeleteReportFormatTestCase
from .test_delete_role import GmpDeleteRoleTestCase
from .test_delete_scanner import GmpDeleteScannerTestCase
from .test_delete_schedule import GmpDeleteScheduleTestCase
from .test_delete_tag import GmpDeleteTagTestCase
from .test_delete_target import GmpDeleteTargetTestCase
from .test_delete_task import GmpDeleteTaskTestCase
from .test_delete_user import GmpDeleteUserTestCase
from .test_describe_auth import GmpDescribeAuthCommandTestCase
from .test_empty_trashcan import GmpEmptyTrashcanCommandTestCase
from .test_get_agent import GmpGetAgentTestCase
from .test_get_agents import GmpGetAgentsTestCase
from .test_get_aggregates import GmpGetAggregatesTestCase
from .test_get_alert import GmpGetAlertTestCase
from .test_get_alerts import GmpGetAlertsTestCase
from .test_get_asset import GmpGetAssetTestCase
from .test_get_assets import GmpGetAssetsTestCase
from .test_get_config import GmpGetConfigTestCase
from .test_get_configs import GmpGetConfigsTestCase
from .test_get_credential import GmpGetCredentialTestCase
from .test_get_credentials import GmpGetCredentialsTestCase
from .test_get_feed import GmpGetFeedTestCase
from .test_get_feeds import GmpGetFeedsTestCase
from .test_get_filter import GmpGetFilterTestCase
from .test_get_filters import GmpGetFiltersTestCase
from .test_get_group import GmpGetGroupTestCase
from .test_get_groups import GmpGetGroupsTestCase
from .test_get_info import GmpGetInfoTestCase
from .test_get_info_list import GmpGetInfoListTestCase
from .test_get_note import GmpGetNoteTestCase
from .test_get_notes import GmpGetNotesTestCase
from .test_get_nvt import GmpGetNvtTestCase
from .test_get_nvt_families import GmpGetNvtFamiliesTestCase
from .test_get_nvts import GmpGetNvtsTestCase
from .test_get_override import GmpGetOverrideTestCase
from .test_get_overrides import GmpGetOverridesTestCase
from .test_get_permission import GmpGetPermissionTestCase
from .test_get_permissions import GmpGetPermissionsTestCase
from .test_get_port_list import GmpGetPortListTestCase
from .test_get_port_lists import GmpGetPortListsTestCase
from .test_get_preference import GmpGetPreferenceTestCase
from .test_get_preferences import GmpGetPreferencesTestCase
from .test_get_report import GmpGetReportTestCase
from .test_get_report_format import GmpGetReportFormatTestCase
from .test_get_report_formats import GmpGetReportFormatsTestCase
from .test_get_reports import GmpGetReportsTestCase
from .test_get_result import GmpGetResultTestCase
from .test_get_results import GmpGetResultsTestCase
from .test_get_role import GmpGetRoleTestCase
from .test_get_roles import GmpGetRolesTestCase
from .test_get_scanner import GmpGetScannerTestCase
from .test_get_scanners import GmpGetScannersTestCase
from .test_get_schedule import GmpGetScheduleTestCase
from .test_get_schedules import GmpGetSchedulesTestCase
from .test_get_setting import GmpGetSettingTestCase
from .test_get_settings import GmpGetSettingsTestCase
from .test_get_system_reports import GmpGetSystemReportsTestCase
from .test_get_tag import GmpGetTagTestCase
from .test_get_tags import GmpGetTagsTestCase
from .test_get_target import GmpGetTargetTestCase
from .test_get_targets import GmpGetTargetsTestCase
from .test_get_task import GmpGetTaskTestCase
from .test_get_tasks import GmpGetTasksTestCase
from .test_get_user import GmpGetUserTestCase
from .test_get_users import GmpGetUsersTestCase
from .test_get_version import GmpGetVersionCommandTestCase
from .test_help import GmpHelpTestCase
from .test_import_config import GmpImportConfigTestCase
from .test_import_report_format import GmpImportReportFormatTestCase
from .test_import_report import GmpImportReportTestCase
from .test_modify_agent import GmpModifyAgentTestCase
from .test_modify_alert import GmpModifyAlertTestCase
from .test_modify_asset import GmpModifyAssetTestCase
from .test_modify_auth import GmpModifyAuthTestCase
from .test_modify_config import GmpModifyConfigTestCase
from .test_modify_config_set_comment import GmpModifyConfigSetCommentTestCase
from .test_modify_config_set_name import GmpModifyConfigSetNameTestCase
from .test_modify_config_set_family_selection import (
    GmpModifyConfigSetFamilySelectionTestCase,
)
from .test_modify_config_set_nvt_preference import (
    GmpModifyConfigSetNvtPreferenceTestCase,
)
from .test_modify_config_set_nvt_selection import (
    GmpModifyConfigSetNvtSelectionTestCase,
)
from .test_modify_config_set_scanner_preference import (
    GmpModifyConfigSetScannerPreferenceTestCase,
)
from .test_modify_credential import GmpModifyCredentialTestCase
from .test_modify_filter import GmpModifyFilterTestCase
from .test_modify_group import GmpModifyGroupTestCase
from .test_modify_note import GmpModifyNoteTestCase
from .test_modify_override import GmpModifyOverrideTestCase
from .test_modify_permission import GmpModifyPermissionTestCase
from .test_modify_port_list import GmpModifyPortListTestCase
from .test_modify_report_format import GmpModifyReportFormatTestCase
from .test_modify_role import GmpModifyRoleTestCase
from .test_modify_scanner import GmpModifyScannerTestCase
from .test_modify_schedule import GmpModifyScheduleTestCase
from .test_modify_setting import GmpModifySettingTestCase
from .test_modify_tag import GmpModifyTagTestCase
from .test_modify_target import GmpModifyTargetTestCase
from .test_modify_task import GmpModifyTaskCommandTestCase
from .test_modify_user import GmpModifyUserTestCase
from .test_move_task import GmpMoveTaskTestCase
from .test_protocol_version import GmpProtocolVersionTestCase
from .test_restore import GmpRestoreTestCase
from .test_resume_task import GmpResumeTaskTestCase
from .test_start_task import GmpStartTaskTestCase
from .test_stop_task import GmpStopTaskTestCase
from .test_sync_cert import GmpSyncCertCommandTestCase
from .test_sync_config import GmpSyncConfigCommandTestCase
from .test_sync_feed import GmpSyncFeedCommandTestCase
from .test_sync_scap import GmpSyncScapCommandTestCase
from .test_test_alert import GmpTestAlertTestCase
from .test_trigger_alert import GmpTriggerAlertTestCase
from .test_verify_agent import GmpVerifyAgentTestCase
from .test_verify_report_format import GmpVerifyReportFormatTestCase
from .test_verify_scanner import GmpVerifyScannerTestCase
from .test_with_statement import GmpWithStatementTestCase



# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv8TestCase
from .testcmds import *  # pylint: disable=wildcard-import


class Gmpv8CloneTicketTestCase(GmpCloneTicketTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateCredentialTestCase(GmpCreateCredentialTestCase, Gmpv8TestCase):

    pass


class Gmpv8CreateFilterTestCase(GmpCreateFilterTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreatePermissionTestCase(GmpCreatePermissionTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateScheduleTestCase(GmpCreateScheduleTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateTagTestCase(GmpCreateTagTestCase, Gmpv8TestCase):
    pass


class Gmpv8CreateTargetCommandTestCase(
    GmpCreateTargetCommandTestCase, Gmpv8TestCase
):
    pass


class Gmpv8CreateTicketTestCase(GmpCreateTicketTestCase, Gmpv8TestCase):
    pass


class Gmpv8DeleteTicketTestCase(GmpDeleteTicketTestCase, Gmpv8TestCase):

    pass


class Gmpv8GetAggregatesTestCase(GmpGetAggregatesTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTicketTestCase(GmpGetTicketTestCase, Gmpv8TestCase):
    pass


class Gmpv8GetTargetsTestCase(GmpGetTargetsTestCase, Gmpv8TestCase):

    pass


class Gmpv8GetVulnerabilitiesTestCase(
    GmpGetVulnerabilitiesTestCase, Gmpv8TestCase
):

    pass


class Gmpv8GetVulnerabilityTestCase(GmpGetVulnerabilityTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyReportFormatTestCase(
    GmpModifyReportFormatTestCase, Gmpv8TestCase
):
    pass


class Gmpv8ModifyTestCase(GmpModifyTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyFilterTestCase(GmpModifyFilterTestCase, Gmpv8TestCase):

    pass


class Gmpv8ModifyPermissionTestCase(GmpModifyPermissionTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyScheduleTestCase(GmpModifyScheduleTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyTagTestCase(GmpModifyTagTestCase, Gmpv8TestCase):
    pass


class Gmpv8ModifyTicketTestCase(GmpModifyTicketTestCase, Gmpv8TestCase):
    pass


class Gmpv8ProtocolVersionTestCase(GmpProtocolVersionTestCase, Gmpv8TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2020 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.connections import (
    SSHConnection,
    DEFAULT_SSH_PORT,
    DEFAULT_SSH_USERNAME,
    DEFAULT_SSH_PASSWORD,
    DEFAULT_HOSTNAME,
)


class SSHConnectionTestCase(unittest.TestCase):
    def test_init_no_args(self):
        ssh_connection = SSHConnection()

        self.check_ssh_connection_for_default_values(ssh_connection)

    def test_init_with_none(self):
        ssh_connection = SSHConnection(
            timeout=None, hostname=None, port=None, username=None, password=None
        )

        self.check_ssh_connection_for_default_values(ssh_connection)

    def check_ssh_connection_for_default_values(self, ssh_connection):
        self.assertIsInstance(ssh_connection, SSHConnection)
        self.assertEqual(ssh_connection.hostname, DEFAULT_HOSTNAME)
        self.assertEqual(ssh_connection.port, DEFAULT_SSH_PORT)
        self.assertEqual(ssh_connection.username, DEFAULT_SSH_USERNAME)
        self.assertEqual(ssh_connection.password, DEFAULT_SSH_PASSWORD)
